#ifndef JOB_DISCONNECTFROMMIXXX_H
#define JOB_DISCONNECTFROMMIXXX_H

#include "prokyon.h"

#include "jobbase.h"

class Job_DisconnectFromMixxx : public JobBase  {
public:
    Job_DisconnectFromMixxx();

    int type() {
        return JOB_DISCONNECT_FROM_MIXXX;
    }

    void run();

    ~Job_DisconnectFromMixxx();
};

#endif
